@@ -1,18 +1,13 @@
 """
-o2tuner module
+o2tuner main module
 """
 
 import sys
 from pkg_resources import require
 from o2tuner.argumentparser import O2TunerArgumentParser
-from o2tuner.o2tuner import O2Tuner, O2TunerError
-from o2tuner.backends import OptunaHandler
+from o2tuner.tuner import O2TunerError
 from o2tuner.log import Log
-
-
-def objective(trial):
-    x_var = trial.suggest_float("x", -10, 10)
-    return (x_var-2)**2
+from o2tuner.run import run
 
 
 LOG = Log()
@@ -20,7 +15,7 @@ LOG = Log()
 
 def entrypoint():
     arg_parser = O2TunerArgumentParser()
-    arg_parser.gen_config_help(O2Tuner.get_default_conf())
+    # arg_parser.gen_config_help(O2Tuner.get_default_conf())
     args = arg_parser.parse_args()
 
     LOG.set_quiet(args.quiet)
@@ -40,20 +35,12 @@ def process_actions(args):
         print(f"{__package__} {ver}")
         return
 
-    optuna_handler = OptunaHandler()
-    optuna_handler.set_objective(objective)
-
-    # Create and run the tuner
-    tuner = O2Tuner(optuna_handler)
-
     if args.action in ["run"]:
-        process_run(tuner, args)
+        process_run(args)
     else:
         assert False, "invalid action"
 
 
-def process_run(o2_tuner, args):
+def process_run(args):
     if args.action == "run":
-        LOG.info("Running ...")
-        o2_tuner.init(n_trials=50)
-        o2_tuner.run()
+        run(args)
